/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific:
   main-programmer: Benjamin Grauer
   co-programmer: ...
*/

/*!
 * @file load_param_class_description.h
 * A Class and macro-functions, that makes our lives easy to load-in parameters
 */

#ifndef _LOAD_PARAM_CLASS_DESCRIPTION_H
#define _LOAD_PARAM_CLASS_DESCRIPTION_H

#include "load_param_description.h"
#include <set>

// Forward Declaration //
class MultiType;

//! A class for descriptions of a loadable module
class LoadParamClassDescription
{
public:
  LoadParamClassDescription(const std::string& className);
  ~LoadParamClassDescription();

  bool operator==(const std::string& className) const { return this->className == className; };
  bool operator==(const LoadParamClassDescription& classDescr) const { return this->className == classDescr.className; };
  bool operator<(const LoadParamClassDescription& classDescr) const { return this->className < classDescr.className; }

  static LoadParamClassDescription* addClass(const std::string& className);
  LoadParamDescription* addParam(const std::string& paramName);

  static void deleteAllDescriptions();

  static void printAll(const std::string& fileName = "");
  static std::list<std::string> searchClassWithShort(const std::string& classNameBegin);
  //  static const LoadParamDescription* getClass(const std::string& className);

private:
  typedef std::set<LoadParamClassDescription>  ClassDescriptionSet;
  typedef std::set<LoadParamDescription>       ParamDescriptionSet;

  static bool                                  parametersDescription;  //!< if parameter-description should be enabled.
  static ClassDescriptionSet*                  classList;              //!< a list, that stores all the loadable classes. (after one instance has been loaded)
  std::string                                  className;              //!< name of the class

  ParamDescriptionSet                          parameters;              //!< List of parameters this class knows.
};

#endif /* _LOAD_PARAM_CLASS_DESCRIPTION_H */
