/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific:
   main-programmer: Benjamin Grauer
   co-programmer: ...
*/

/*!
 * @file load_param_description.h
 * A Class and macro-functions, that makes our lives easy to load-in parameters
 */

#ifndef _LOAD_PARAM_DESCRIPTION_H
#define _LOAD_PARAM_DESCRIPTION_H

#include <vector>
#include <string>

// Forward Declaration //
class MultiType;

/************************
*** DESCRIPTION STUFF ***
************************/
//! A class that handles the description of loadable parameters
class LoadParamDescription
{
public:
  LoadParamDescription(const std::string& paramName);
  ~LoadParamDescription();

  bool operator==(const std::string& paramName) const { return this->name == paramName; };
  bool operator==(const LoadParamDescription& paramDescr) const { return this->name == paramDescr.name; };
  bool operator<(const LoadParamDescription& paramDescr) const { return this->name < paramDescr.name; };

  void setDescription(const std::string& descriptionText);
  /** @returns the descriptionString */
  const std::string& getDescription() { return this->description; };

  void print() const;

private:
  const std::string          name;                  //!< The Name of the Parameter.
  unsigned int               parameterCount;        //!< The Count of parameters.
  std::string                description;           //!< A longer description about this function.

  std::vector<std::string>   types;
  std::vector<std::string>   defaultValues;

};

#endif /* _LOAD_PARAM_DESCRIPTION_H */
